import ReactDOM from "react-dom/client";
import React, {useEffect, useRef, useState} from "react";
import { Compiler } from "../src";

const sourceCode = `
class LowcodeComponent extends Component {
  state = {
  }

  componentDidMount() {}

  componentWillUnmount() {}
}
`
const View = () => {
  const compilerRef = useRef<Compiler>()
  const [code, setCode] = useState('')

  useEffect(() => {
    if (!compilerRef.current) {
      compilerRef.current = new Compiler({
        sourceCode: sourceCode,
        fileNameOrPath: 'LowcodeComponent.tsx',
        hooks: {
          onload: async (_core) => {
            console.log(_core.code)
            setCode(_core.code)
          },
          onPrettier: async (_code: string) => {},
          onError: async (_e: any) => {},
          onInserted: async (_res) => {
            console.log(_res)
            setCode(compilerRef?.current?.code || '')
          },
          onRemoved: async (_data: boolean) => {
            console.log(compilerRef?.current?.code || '');
            setCode(compilerRef?.current?.code || '')
          }
        }
      })
    }
  }, [])
  const addVariable1 = async () => {
    try {
      await compilerRef.current?.createProperty?.('State', {
        comment: "测试字段",
        value: '',
        name: "test",
        type: "string",
        params: []
      }, { override: true})
    }catch (e) {
      console.log(e)
    }
  }

  const delVariable1 = async () => {
    try {
      await compilerRef.current?.deleteProperty?.('State', 'test')
    }catch (e) {
      console.log(e)
    }
  }
  const addVariable2 = async () => {
    try {
      await compilerRef.current?.createProperty?.('State',{
        comment: "测试字段",
        value: '',
        name: "test2",
        type: "string",
        params: []
      }, { override: true})
    }catch (e) {
      console.log(e)
    }
  }
  const delVariable2 = async () => {
    try {
      await compilerRef.current?.deleteProperty?.('State','test2')
    }catch (e) {
      console.log(e)
    }
  }
  const addVariable3 = async () => {
    try {
      await compilerRef.current?.createProperty?.('State',{
        comment: "测试字段",
        value: '鹅鹅鹅饿',
        name: "test2",
        type: "string",
        params: []
      }, { override: true})
    }catch (e) {
      console.log(e)
    }
  }
  const addVariable4 = async () => {
    try {
      await compilerRef.current?.createProperty?.('Function', {
        comment: "测试方法",
        value: 'console.log(123)',
        name: "testFunction",
        params: [],
        type: 'function'
      }, { override: true})
    }catch (e) {
      console.log(e)
    }
  }

  const delVariable4 = async () => {
    try {
      await compilerRef.current?.deleteProperty?.('Function', 'testFunction')
    }catch (e) {
      console.log(e)
    }
  }
  return (
    <div>
      <div>
        <button onClick={addVariable1}>增加变量1</button>
        <button onClick={delVariable1}>删除变量1</button>
        <button onClick={addVariable2}>增加变量2</button>
        <button onClick={delVariable2}>删除变量2</button>
        <button onClick={addVariable3}>增加变量3</button>
        <button onClick={addVariable4}>增加方法</button>
        <button onClick={delVariable4}>删除方法</button>
      </div>

      <div>
        <pre>{code}</pre>
      </div>
    </div>
  )
}
ReactDOM.createRoot(document.getElementById('root')!).render(
  <React.Fragment>
    <View/>
  </React.Fragment>,
)
