import { defineConfig } from 'vite';
import dts from "vite-plugin-dts";
import path from "path";
import react from "@vitejs/plugin-react";

const common = [
  'mobx-react-lite',
  'react',
  'typescript'
]
export default defineConfig({
  build: {
    rollupOptions: {
      external: (id, _s, _d) => {
        if (common.includes(id)) {
          return true;
        }
        return /^@lowcode-set-up-platform/.test(id)
      }
    },
    outDir: 'lib',
    lib: {
      entry: './src/index.ts',
      fileName: (f, n) => {
        if (f == 'es') {
          return `${n}.${f}m.js`
        }
        if (f === 'cjs') {
          return `${n}.js`
        }
        return `${n}.${f}.js`

      },
      formats: ['es', 'cjs']
    }
  },
  plugins: [
    react(),
    dts({
      outDir: 'lib', // 将类型文件直接生成到 lib 目录
      include: ['./src/**'], // 指定包含的文件
      entryRoot: path.resolve(__dirname, './src'), // 将 src 目录作为类型文件生成的根路径
  })]
});
